// This file is part of the disk cataloger Wssindex, but was written by a
// 3rd party.  See comments below for author and licensing information.

// This comes from https://wiki.qt.io/Clickable_QLabel
// License is Creative Commons Attribution-ShareAlike 2.5 Generic.
// Modified to trigger on mouse release instead of mouse press.

#include "3rdparty/clickablelabel.h"
#include <QtDebug>
#include <QEvent>

ClickableLabel::ClickableLabel(const QString& text, QWidget *parent) :
	QLabel(parent)
	{
	this->setText(text);
	this->setAttribute(Qt::WA_Hover);
	}

ClickableLabel::~ClickableLabel()
	{
	}

ClickableLabel::ClickableLabel(QWidget *parent) : QLabel(parent)
	{
	}

void ClickableLabel::mouseReleaseEvent(QMouseEvent * /* event */)
	{
	Q_EMIT clicked();
	}

// This is derived from
// https://forum.qt.io/topic/32344/solved-making-qlabel-hover-aware/10
// but very little of the original remains.
bool ClickableLabel::event(QEvent *event)
	{
	switch(event->type())
		{
		case QEvent::HoverMove:
			return true;

		case QEvent::HoverEnter:
			Q_EMIT labelHovered();
			return true;

		case QEvent::HoverLeave:
			Q_EMIT labelUnhovered();
			return true;

		default:
			break;
		}
	return QLabel::event(event);
	}
