// This file is part of the disk cataloger Wssindex, but was written by a
// 3rd party.  See comments below for author and licensing information.

// This is based on a posting at
// https://forum.qt.io/topic/29859/solved-trying-to-fix-aspect-ratio-of-a-widget-big-problems-with-layouts/5

// The purpose here is to preserve the aspect ratio of the disk indexing animations
// while letting them expand as large as possible.

#include "3rdparty/qsvgaspect.h"

#include <QPainter>
#include <QSvgRenderer>
#include <QDebug>

QSvgAspect::QSvgAspect()
	{
	}

// aspect is width/height of the SVG viewBox
void QSvgAspect::setSvgAspectRatio(double aspect)
	{
	imageAspect = aspect;
	}

QRect QSvgAspect::centeredViewport(int width, int height)
	{
	int heightFromWidth = static_cast<int>(width/imageAspect);
	int widthFromHeight = static_cast<int>(height*imageAspect);

	if (heightFromWidth <= height)
		return QRect(0,(height-heightFromWidth)/2, width, heightFromWidth);
	else
		return QRect(static_cast<int>((width-widthFromHeight)/2.0), 0, widthFromHeight, height);
	}

void QSvgAspect::paintEvent(QPaintEvent *)
	{
	QPainter painter(this);
	QSvgRenderer *r = this->renderer();
	painter.setViewport(centeredViewport(width(), height()));
	r->render(&painter, QRectF(QPoint(0,0), size()));
	}
