// This file is part of the disk cataloger Wssindex, but was derived from code written by a
// 3rd party.  See comments below for author and licensing information.

// From post #4 by jpn at https://www.qtcentre.org/threads/6252-QTableWidget-NW-corner-header-item
// Additional credits below

#include <3rdparty/qtablewidgetoverride.h>

#include <QApplication>
#include <QClipboard>

// This override of QTableWidget adds horizontal and vertical titles in the Wssindex sort
// speed table.  The titles are hard-coded, so this is not a general purpose routine.

TableWidget::TableWidget(QWidget *parent) : QTableWidget(parent)
	{
	QAbstractButton *btn = findChild<QAbstractButton *>();
	if(btn)
		{
		btn->setText(tr("         Threads\nIteration"));
		btn->installEventFilter(this);

// adjust the width of the vertical header to match the preferred corner button width
// (unfortunately QAbstractButton doesn't implement any size hinting functionality)
		QStyleOptionHeader opt;
		opt.text = btn->text();
		QSize s = (btn->style()->sizeFromContents(QStyle::CT_HeaderSection, &opt, QSize(), btn).
			expandedTo(QApplication::globalStrut()));
		if(s.isValid())
			{
			verticalHeader()->setMinimumWidth(s.width());
			horizontalHeader()->setMinimumHeight(s.height());
			}
		}
	}

bool TableWidget::eventFilter(QObject *o, QEvent *e)
	{
	if (e->type() == QEvent::Paint)
		{
		QAbstractButton *btn = qobject_cast<QAbstractButton *>(o);
		if(btn)
			{
// paint by hand (borrowed from QTableCornerButton)
			QStyleOptionHeader opt;
			opt.init(btn);
			QStyle::State state = QStyle::State_None;
			if(btn->isEnabled())
				state |= QStyle::State_Enabled;
			if(btn->isActiveWindow())
				state |= QStyle::State_Active;
			if(btn->isDown())
				state |= QStyle::State_Sunken;
			opt.state = state;
			opt.rect = btn->rect();
			opt.text = btn->text(); // this line is the only difference to QTableCornerButton
			opt.position = QStyleOptionHeader::OnlyOneSection;
			QStylePainter painter(btn);
			painter.drawControl(QStyle::CE_Header, opt);
			return true; // eat event
			}
		}
		return false;
	}

// Code below was derived from
// https://stackoverflow.com/questions/1230222/selected-rows-in-qtableview-copy-to-qclipboard
// Purpose is to make control-c copy of results from sort speed table work.

void TableWidget::copy()
	{
	QItemSelectionModel * selection = selectionModel();
	QModelIndexList indexes = selection->selectedIndexes();

	if(indexes.size() < 1)
		return;

// qSort is deprecated
//	qSort(indexes);
	std::sort(indexes.begin(), indexes.end());

// You need a pair of indexes to find the row changes
	QModelIndex previous = indexes.first();
	indexes.removeFirst();
	QString selected_text;
	QModelIndex current;
	Q_FOREACH(current, indexes)
		{
		QVariant data = model()->data(previous);
		QString text = data.toString();
		selected_text.append(text);

// If you are at the start of the row the row number of the previous index
// isn't the same.  Text is followed by a row separator, which is a newline.
		if (current.row() != previous.row())
			selected_text.append(QLatin1Char('\n'));
// Otherwise it's the same row, so append a column separator, which is a tab.
		else
			selected_text.append(QLatin1Char('\t'));
	previous = current;
	}

// add last element
	selected_text.append(model()->data(current).toString());
	selected_text.append(QLatin1Char('\n'));
	qApp->clipboard()->setText(selected_text);
	}

void TableWidget::keyPressEvent(QKeyEvent * event)
	{
	if(event->matches(QKeySequence::Copy) )
		copy();
	else
		QTableWidget::keyPressEvent(event);
	}
