// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "Dialogs/mainwindow.h"
#include "OtherWssi/wssiproto.h"
#include "Threads/binsearchthread.h"
#include "Threads/fillbinthread.h"
#include "Threads/mergesortthread.h"

#include <QApplication>

void MainWindow::doSort(unsigned long *array, unsigned long n,
								int (*cmpf)(const unsigned long, const unsigned long), int force)
	{
// Are multiple threads enabled and are there enough items
// to be sorted to make threading worthwhile?
	int nthread = threadsToUse(force);
	if(1 == nthread || n < 1000)
		{
// May need hourglass cursor if we're here because 1==nthread
		QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
		mergesort(array, n, cmpf);
		QApplication::restoreOverrideCursor();
		return;
		}
	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
// Pick ~sqrt(n*nthread) sort-of-random values, want a multiple
// of nthread-1.
	unsigned long samplecount = static_cast<unsigned long>(nthread-1)
		* static_cast<unsigned long>(sqrt(static_cast<double>(n) / static_cast<double>(nthread)));
	unsigned long step = n / samplecount;
	unsigned long nsamples = 0;
	unsigned long *s = new unsigned long[samplecount];
	for(unsigned long i=step/2; nsamples<samplecount; i+=step)
		{
		s[nsamples++] = array[i];
		}
	mergesort(s, nsamples, cmpf);
	step = nsamples / static_cast<unsigned long>(nthread);
	int part = 0;
	for (unsigned long i=step; part<nthread-1; i+=step)
		{
		s[part++] = s[i];
//		debug_print(s[part-1], QFA("Boundary"));
		}
	int *partnum = new int[n];
	step = n/static_cast<unsigned long>(nthread);
	unsigned long low = 0;
	unsigned long high = step;
	unsigned long *bincount = new unsigned long[static_cast<unsigned long long>(nthread*nthread)];
	memset(bincount, 0, static_cast<size_t>(nthread*nthread)*sizeof(unsigned long));
	BinSearchThread **bst = new BinSearchThread*[static_cast<unsigned long long>(nthread)];
	for(int i=0; i<nthread; i++)
		{
		if(nthread-1 == i)
			high = n;
		bst[i] = new BinSearchThread(nthread, array, s, partnum, bincount+i*nthread, low, high, cmpf);
		bst[i]->start();
		low += step;
		high += step;
		}
	for(int i=0; i<nthread; i++)
		{
		bst[i]->wait();
		delete bst[i];
		}
// How many items in each bin?
	unsigned long *binsize = new unsigned long[static_cast<unsigned long long>(nthread)];
	memset(binsize, 0, static_cast<unsigned long long>(nthread)*sizeof(unsigned long));
	for(int i=0; i<nthread; i++)	// loop over bins
		{
		for(int j=0; j<nthread; j++)	// loop over threads
			{
			binsize[i] += bincount[i + j*nthread];
			}
		}
// Allocate and fill new index array
	unsigned long *binselect = new unsigned long[n];
	FillBinThread **fbt = new FillBinThread*[static_cast<unsigned long long>(nthread)];
	unsigned long binstart = 0;
	for(int i=0; i<nthread; i++)
		{
		fbt[i] = new FillBinThread(array, i, binselect+binstart, partnum, n);
		fbt[i]->start();
		binstart += binsize[i];
		}
	for(int i=0; i<nthread; i++)
		{
		fbt[i]->wait();
		delete fbt[i];
		}
	binstart = 0;
	MergeSortThread **ms = new MergeSortThread*[static_cast<unsigned long long>(nthread)];
	for(int i=0; i<nthread; i++)
		{
		ms[i] = new MergeSortThread(binselect+binstart, binsize[i], cmpf);
		ms[i]->start();
		binstart += binsize[i];
		}
	for(int i=0; i<nthread; i++)
		{
		ms[i]->wait();
		delete ms[i];
		}
	memcpy(array, binselect, n*sizeof(unsigned long));
	delete [] bst;
	delete [] fbt;
	delete [] ms;
	delete [] bincount;
	delete [] binsize;
	delete [] binselect;
	delete [] partnum;
	delete [] s;
	QApplication::restoreOverrideCursor();
	}
