// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "Dialogs/fadeanimation.h"
#include <QApplication>

// FadeAnimation must be called using new (unless duration is zero).
// If it is created on the stack, the animation will finish and the
// message box will be invisible but not closed.
// FadeAnimation deletes itself; the caller does not need to do it.

FadeAnimation::FadeAnimation(QString title, QString text, int duration_sec,
									  QEasingCurve easing )
	{
	this->setAttribute(Qt::WA_DeleteOnClose);
	if(duration_sec > 0)
		{
		fadeBox = new QMessageBox;
		fadeBox->setWindowTitle(title);
		fadeBox->setText(text);
		fadeBox->show();
		fadeAnimation = new QPropertyAnimation(fadeBox, "windowOpacity");
		fadeAnimation->setDuration(1000*duration_sec);
		fadeAnimation->setStartValue(qreal(1.0));
		fadeAnimation->setEndValue(qreal(0.0));
		fadeAnimation->setEasingCurve(easing);
		fadeAnimation->start();
		connect(fadeAnimation, SIGNAL(finished()), SLOT(slot_fadeFinished()));
		connect(fadeBox, SIGNAL(accepted()), SLOT(slot_fadeFinished()));
		}
	else
		{
// If not fading, null these so delete in destructor doesn't crash
		fadeBox = nullptr;
		fadeAnimation = nullptr;
		QMessageBox::information(this, title, text);
		}
	}

FadeAnimation::~FadeAnimation()
	{
	delete fadeBox;
	delete fadeAnimation;
	}

void FadeAnimation::slot_fadeFinished()
	{
	disconnect();
	fadeBox->close();
	}
