// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef FULLSORTDIALOG_H
#define FULLSORTDIALOG_H

#include <QMainWindow>
#include <QTableWidgetItem>

namespace Ui
	{
	class FullSortDialog;
	}

class MainWindow;

class FullSortDialog : public QMainWindow
	{
	Q_OBJECT

public:
	explicit FullSortDialog(QWidget *parent);
	~FullSortDialog() override;

private:
	void restoreSettings();
	Ui::FullSortDialog *fsd;
	void keyPressEvent(QKeyEvent * event) override;
	void wheelEvent(QWheelEvent *event) override;
	QTableWidgetItem *ascending;
	QTableWidgetItem *descending;

protected:
	void closeEvent(QCloseEvent *event) override;

Q_SIGNALS:
	void signal_keyToTable(int, int);
	void signal_sortNeeded();
	void signal_wheelToTable(QPoint, int, Qt::MouseButtons,
										Qt::KeyboardModifiers, Qt::Orientation);

private Q_SLOTS:
	void slot_pushButtonAddKeyClicked();
	void slot_pushButtonCloseClicked();
	void slot_pushButtonMoveKeyDownClicked();
	void slot_pushButtonMoveKeyUpClicked();
	void slot_pushButtonRemoveKeyClicked();
	void slot_pushButtonSortClicked();
	void slot_useTableDoubleClicked(int row, int column);
	};

#endif // FULLSORTDIALOG_H
