// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef INDEXINGDIALOG_H
#define INDEXINGDIALOG_H

#include <QMainWindow>
#include <QBasicTimer>
#include "3rdparty/qsvgaspect.h"
#include "indexwindow.h"

#define ANIMATION_MILLISEC	200
#define HD_ARM_ANGLE_MIN	-6
#define HD_ARM_ANGLE_MAX	20
#define HD_ARM_ANGLE_STEP	1
#define HD_ANGLE_STEP		10
#define USB_COLOR_MIN		0
#define USB_COLOR_MAX		127
#define USB_COLOR_STEP		5
#define CD_ANGLE_STEP		10
#define FLOPPY_SLIDER_MIN	0
#define FLOPPY_SLIDER_MAX	73
#define FLOPPY_SLIDER_STEP	5

namespace Ui
	{
	class IndexingDialog;
	}

class IndexWindow;
class MainWindow;
class MessageLogWindow;

class IndexingDialog : public QMainWindow
	{
	Q_OBJECT

public:
	IndexingDialog(QWidget *parent, MessageLogWindow *ml, struct diskrec *currentVrec, enum disktypes dtype);
	~IndexingDialog() override;

private:
	void keyPressEvent(QKeyEvent * event) override;
	void saveSettings();
	void restoreSettings();
	Ui::IndexingDialog *id;
	class IndexWindow *iw;
	QBasicTimer timer;
	int armAngle;
	int cdAngle;
	int diskAngle;
	int usbColor;
	int sliderPos;
	int netColor;
	bool netSkip;
	bool run_images_backwards;
	void wheelEvent(QWheelEvent *event) override;
	QSvgAspect *svgWidget;
	QString svgAnimation;
	enum disktypes animationType;
	void withingRange(int *value, bool *backwards, int smallest, int biggest, int step);

protected:
	void timerEvent(QTimerEvent *event) override;

Q_SIGNALS:
	void signal_keyToMl(int, int);
	void signal_wheelToMl(QPoint, int, Qt::MouseButtons,
										 Qt::KeyboardModifiers, Qt::Orientation);
public Q_SLOTS:
	void slot_indexIsDone();

private Q_SLOTS:
	void slot_pushbuttonStopClicked();
	};

#endif // INDEXINGDIALOG_H
