// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "Dialogs/indexwindow.h"
#include "Dialogs/indexingdialog.h"
#include "OtherWssi/globalsettings.h"
#include "Dialogs/mainwindow.h"
#include "OtherWssi/wssiproto.h"

#include <QMessageBox>

int IndexWindow::check_duplicate_volname(QString newvolname)
	{
	for(unsigned int i=0; i<Diskno; i++)
		{
		if(newvolname == Vrec[i].VolName)
			{
			oldVolno = i;
			QMessageBox msgBox;
			msgBox.setText(tr("<html><head/><body><p>Volume label already exists in database.<p>"
				"Label is %1</p></body></html>").arg(newvolname));
			QPushButton *replaceButton = msgBox.addButton(tr("Replace"), QMessageBox::ActionRole);
			QPushButton *replaceAndCopyButton = msgBox.addButton(tr("Replace and copy comments"), QMessageBox::ActionRole);
			replaceAndCopyButton->setToolTip(tr("Could be slow if this disk holds a large number of files"));
			QPushButton *cancelButton = msgBox.addButton(tr("Don't index"), QMessageBox::ActionRole);
			msgBox.exec();

			if(msgBox.clickedButton() == replaceButton)
				return(REPLACE);
			if(msgBox.clickedButton() == replaceAndCopyButton)
				return(REPLACE_AND_COPY);
			if(msgBox.clickedButton() == cancelButton)
				return(DONT_REPLACE);
			}
		}
	return(NOT_DUPLICATE);
	}

void IndexWindow::copy_and_delete(unsigned int oldDisk)
	{
	unsigned int last_old_subdir = Subno + 1;
	unsigned long first_subdir_match = Nfold;
	unsigned long old_first_file = Vrec[oldDisk].firstOnDisk;
// Once we start changing existing data, the display models cannot
// be trusted
	mainWindowPtr->Ftm->setFileModelValidity(false);
	mainWindowPtr->Vtm->setVolModelValidity(false);
	for(unsigned long old=old_first_file; old<Nfold; old++)
		{
		struct filerec *dr_old = Dr + old;
		if(dr_old->Volno != oldDisk)
			continue;
		if(hasNoComment(dr_old) && hasNoCategory(dr_old) && hasNoExtraInfo(dr_old))
			continue;
		bool old_in_arc = false;
		bool old_is_arc = false;
		unsigned long subold = dr_old->Subdirno;
		unsigned long oldnsub = 0;
		struct filerec *dr_subold = Dr + subold;
		if(inArc(dr_old))
			{
			old_in_arc = true;
			oldnsub = subold;
			subold = dr_subold->Subdirno;
//			dr_subold = Dr + subold;
			}
		unsigned short old_ExtOffset = dr_old->ExtOffset;
		unsigned short old_nsubExtOffset = 0;	// initialized to quiet compiler warning
		struct filerec *dr_oldnsub = nullptr;			// initialized to quiet compiler warning;
		if(old_in_arc)
			{
			dr_oldnsub = Dr + oldnsub;
			old_nsubExtOffset = dr_oldnsub->ExtOffset;
			}
		bool old_subdir_changed = (subold != last_old_subdir);
		if(old_subdir_changed)
			first_subdir_match = Nfold;
		unsigned long start = Copy_across_subdirs ? Nfold : first_subdir_match;
		last_old_subdir = subold;
		unsigned long last_new_subdir = Subno + 1;
		bool found_matching_new_subdir = false;
		for(unsigned long newf=start; newf<Nofile; newf++)
			{
			struct filerec *dr_new = Dr + newf;

			bool new_in_arc = false;
			unsigned long subnew = dr_new->Subdirno;
			struct filerec *dr_subnew = Dr + subnew;
			unsigned long newnsub = 0;		// initialized to quiet compiler warning;
			if(inArc(dr_new))
				{
				new_in_arc = true;
				newnsub = subnew;
				subnew = dr_subnew->Subdirno;
//				dr_subnew = Dr + subnew;
				}

			if(!Copy_across_subdirs)
				{
				if(last_new_subdir != subnew)
					{
					last_new_subdir = subnew;
					if(found_matching_new_subdir)
						break;
					else
						{
						if(SubDir[subold] == SubDir[subnew])
							{
							found_matching_new_subdir = true;
							first_subdir_match = newf;
							}
						else
							continue;
						}
					}
				else
					{
					if(!found_matching_new_subdir)
						continue;
					}
				}

			if(namecomp(dr_old, dr_new, COMPARE_FILENAME, COMPARE_NOMORE))
				continue;

			unsigned short new_ExtOffset = dr_new->ExtOffset;

			if(dr_old->Lfn.midRef(old_ExtOffset).compare(dr_new->Lfn.midRef(new_ExtOffset), Qt::CaseInsensitive))
				{
				bool new_is_arc = false;
				if( !Ignore_arc_ext)
					continue;
				for(int j=0; j<NLIBTYPE; j++)
					{
					if(TYPE_SELF_EXTRACTING == Extract[j].type)
						continue;
					if(Extract[j].nameRegexp.indexIn(dr_old->Lfn.mid(old_ExtOffset)) >= 0)
						old_is_arc = true;
					if(Extract[j].nameRegexp.indexIn(dr_new->Lfn.mid(new_ExtOffset)) >= 0)
						new_is_arc = true;
					}
				if( !(old_is_arc && new_is_arc))
					continue;
				}
			if(0 != SubDir[subold].compare(SubDir[subnew], Qt::CaseInsensitive))
				continue;
// For comment copy from archive member to archive member, require matching
// archive file names, but maybe not extensions.
			if(old_in_arc && new_in_arc)
				{
				struct filerec *dr_newnsub = Dr + newnsub;
				if(namecomp(dr_oldnsub, dr_newnsub, COMPARE_FILENAME, COMPARE_NOMORE))
					continue;
				if( !Ignore_arc_ext)
					{
					if(dr_oldnsub->Lfn.midRef(old_nsubExtOffset).compare(dr_newnsub->Lfn.midRef(dr_newnsub->ExtOffset), Qt::CaseInsensitive))
						continue;
					}
				}
// For comment copy between archive member and any file, require matching size
// and date
			if(old_in_arc != new_in_arc)
				{
				if(dr_old->Dsize != dr_new->Dsize) continue;
				if(dr_old->Ddate != dr_new->Ddate) continue;
				}
// If a comment was extracted from an archive file, it replaces
// any previously existing comment
			if(hasNoComment(dr_new) && hasComment(dr_old))
				{
				dr_new->Comment = dr_old->Comment;
				setHasComment(dr_new);
				}
			if(hasCategory(dr_old))
				{
				dr_new->Category = dr_old->Category;
				setHasCategory(dr_new);
				}
			if(hasExtraInfo(dr_old))
				{
				dr_new->ExtraInfo = dr_old->ExtraInfo;
				setHasExtra(dr_new);
				}
// If we get this far, we have matched the file, but with archive stuff there
// is the possibility of multiple matches.  Otherwise we could save time by
// breaking here.
			}
		}
	delete_disk(oldDisk);
	}

// Note: this is used when a disk is removed because it is replaced
// during indexing.  For disks deleted from the volume list or when
// purging duplicates, see MainWindow::removews

void IndexWindow::delete_disk(unsigned int oldDisk)
	{
	Diskno--;
	Q_EMIT signal_diskListChanged();
	unsigned long first_deleted = Vrec[oldDisk].firstOnDisk;
	unsigned long first_not_deleted;
	if(oldDisk < Diskno)
		{
		first_not_deleted = Vrec[oldDisk+1].firstOnDisk;
		}
	else
		first_not_deleted = Nofile;
	unsigned long nfremove = first_not_deleted - first_deleted;

// Move disk records back one starting from first after deleted disk
	for(unsigned long j=oldDisk; j<Diskno; j++)
		{
		Vrec[j] = Vrec[j+1];
		Vrec[j].firstOnDisk -= nfremove;
		}

// Loop over files.  If file is on deleted disk, increment count of deleted
//	files and free storage for any comment or category.  If file follows
//	deleted disk, move file record back, adjust volume number field and
//	subdir field for archive members (which actually has index of containing
//	archive file

	for(unsigned long j=first_not_deleted; j<Nofile; j++)
		{
		Dr[j-nfremove] = Dr[j];
		Dr[j-nfremove].Volno--;
		if(inArc(Dr+j))
			Dr[j-nfremove].Subdirno -= nfremove;
		}

	Nofile -= nfremove;

// Loop over subdirectories.  Move disk numbers in SubDisk array back.  If
//	subdirectory is on deleted disk, increment count of deleted subdirectories.
//	Adjust disk number for subdirectories following deleted subdirectories.

	unsigned long first = 0;
	unsigned long nsremove = 0;
	for(unsigned long k=1; k<Subno; k++)
		{
		SubDisk[k-nsremove] = SubDisk[k];
		SubDir[k-nsremove] = SubDir[k];
		if(SubDisk[k] == oldDisk)
			{
			nsremove++;
			if(first == 0)
				first = k;
			}
		else
			{
			if(SubDisk[k] > oldDisk)
				SubDisk[k-nsremove] -= 1;
			}
		}

// If any subdirectories have been removed, loop over files again adjusting
//	subdirectory numbers for true subdirectories (not archive members).
	if(nsremove > 0)
		{
		for(unsigned long j=0; j<Nofile; j++)
			{
			struct filerec *dr_j = Dr + j;
			if(inArc(dr_j))
				continue;
			if(dr_j->Subdirno >= first)
				dr_j->Subdirno -= nsremove;
			}
		}

	Subno -= nsremove;
	SubnoBeforeIndexing -= nsremove;
// -1 here is for the volume .id record that was removed but not counted in nsremove
	NofileBeforeIndexing -= nfremove - nsremove - 1;
	NoPlainFiles -= nfremove - nsremove - 1;
	mainWindowPtr->statusChanged(true);
	return;
	}
