// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "Dialogs/indexwindow.h"
#include "ui_indexwindow.h"
#include "Dialogs/mainwindow.h"
#include "OtherWssi/globalsettings.h"
#include "OtherWssi/initialpos.h"
#include "OtherWssi/wssiproto.h"

void IndexWindow::restoreSettings()
	{
	QSettings settings("WSS-DDC", "Wssindex\\Geometry");
	if(settings.contains("IndexGeometrySize"))
		{
		QSize size = settings.value("IndexGeometrySize").toSize();
		resize(size);
		}
	if(settings.contains("IndexGeometryPos"))
		{
		QPoint pos = settings.value("IndexGeometryPos").toPoint();
		move(pos);
		forceOnscreen(this);
		}
	else
		{
		this->show();
		move(mainWindowPtr->offCenter(this->frameGeometry(), INDEXMAIN_OFFSET));
		}
	}

void IndexWindow::slot_buttonBrowseClicked()
	{
	QString path = QFileDialog::getExistingDirectory(this,
										 tr("Indexing path"), tr("/"));
	if (!path.isEmpty())
		{
		ui->lineEdit_startdir->setText(QDir::toNativeSeparators(path.mid(2)));
		}
	}

void IndexWindow::slot_buttonSaveTheseSettings()
	{
	QSettings options("WSS-DDC", "Wssindex\\Options");
	options.setValue("Indexing_drive_letter[0]", drive_letter[0]->currentText().at(0).toLatin1());
	options.setValue("Indexing_drive_letter[1]", drive_letter[1]->currentText().at(0).toLatin1());
	options.setValue("Serialization_format", ui->lineEdit_serString->text());
	options.setValue("Next_serial_number", ui->spinBox_serNum->value());
	options.setValue("IndexTimeFiltering", ui->checkBox_useExclusions->isChecked());
	options.setValue("Extract_opt", Extract_opt);
	}

void IndexWindow::slot_indexSettingsClicked()
	{
	Q_EMIT signal_settingsClicked();
	}

void IndexWindow::slot_extractionOptionChanged(int radiobutton)
	{
	Extract_opt = static_cast<ExtractOpts>(radiobutton);
	}
