// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "Dialogs/mainwindow.h"
#include "ui_mainwindow.h"
#include "OtherWssi/globalsettings.h"
#include "OtherWssi/tablelayout.h"

void MainWindow::slot_cellEdited(QModelIndex index, QString newValue)
	{
	int row = index.row();
	int column = index.column();
	unsigned long filenum = Sortindx[static_cast<unsigned long>(row/rowsPerItem) + file_start];
	struct filerec *dr_k = Dr + filenum;

	int itemrow = row % rowsPerItem;
// Is this category, comment or extra info?
	newValue = newValue.trimmed();
	if(itemrow == categoryRow && column == categoryCol)
		{
		if(newValue != dr_k->Category)
			{
			dr_k->Category = newValue;
			setCategoryEdited(dr_k);
			if(dr_k->Category.isEmpty() && hasCategory(dr_k))
				{
				setHasNoCategory(dr_k);
				}
			else
				setHasCategory(dr_k);
			statusChanged(true);
			}
		}
	else if(itemrow == commentRow && column == commentCol)
		{
		if(newValue != dr_k->Comment)
			{
			dr_k->Comment = newValue;
			setCommentEdited(dr_k);
			if(dr_k->Comment.isEmpty() && hasComment(dr_k))
				setHasNoComment(dr_k);
			else
				setHasComment(dr_k);
			statusChanged(true);
			}
		}
	else if(itemrow == extraRow && column == extraCol)
		{
		if(newValue != dr_k->ExtraInfo)
			{
			dr_k->ExtraInfo = newValue;
			setExtraEdited(dr_k);
			if(dr_k->ExtraInfo.isEmpty() && hasExtraInfo(dr_k))
				setHasNoExtra(dr_k);
			else
				setHasExtra(dr_k);
			statusChanged(true);
			}
		}
	else if(itemrow == volumeRow && column == volumeCol)
		{
		QString newvol = newValue.trimmed();
		if(newvol.isEmpty())
			{
			QMessageBox::warning(this, tr("Illegal volume name"), tr("Volume name cannot be blank"));
			return;
			}
		unsigned int volnum = dr_k->Volno;
		if(newValue != Vrec[volnum].VolName)
			{
			Vrec[volnum].VolName = newValue;
			unsigned long first_renamed = Vrec[volnum].firstOnDisk;
			for(unsigned int k=first_renamed; k<Nofile; k++)
				{
				dr_k = Dr + k;
				if(volnum != dr_k->Volno)
					break;
				setVolEdited(dr_k);
				}
			Changed = true;
			Q_EMIT signal_diskListChanged();
			}
		}
	else
		QMessageBox::warning(this, tr("Error"),
			tr("Only volume name, categories, comments and extra info are editable"));

	ui->tableView->setSelectionBehavior(QAbstractItemView::SelectItems);
	ui->tableView->setCurrentIndex(index);
	}

// If somebody (e.g. vollistwindow) has changed volume names, disk name
// pulldowns need to be updated.
void MainWindow::slot_relayDisknameChange()
	{
	Q_EMIT signal_diskListChanged();
	}
