// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "Dialogs/mainwindow.h"
#include "ui_mainwindow.h"
#include "OtherWssi/globalsettings.h"

#include <QFontDialog>
#include <QtDebug>

void MainWindow::slot_pickFont()
	{
// Not using QFontDialog::getFont() because Qt 5 bug disables X-to-close
// See https://bugreports.qt.io/browse/QTBUG-32240
// Seems to have been fixed at some point
	QFontDialog *qf = new QFontDialog(ui->tableView->font(), this);
	if(UseModernStyle)
		qf->setStyleSheet(QLatin1String("QFontDialog {" BLUE_WASH "}"));
	qf->setWindowFlags(MyWindowFlags);
	qf->setModal(true);
	qf->exec();
	if(QDialog::Accepted == qf->result())
		{
		*Font_filelist = qf->selectedFont();
		ui->tableView->setFont(*Font_filelist);

// This is to work around an apparent Qt bug.   When the header font is changed.
// the row height adjusts to fit, but the font goes to some too-small default.
// Straightforward code would be just
//		ui->tableView->horizontalHeader()->setFont(*Font_filelist);
// Not sure if it's safe to delete the horizontal header while it's in use,
// so wait until a replacement is in place.
		QHeaderView *replacementFileViewHeader = new QHeaderView(Qt::Horizontal);
		replacementFileViewHeader->setFont(*Font_filelist);
		ui->tableView->setHorizontalHeader(replacementFileViewHeader);
		ui->tableView->horizontalHeader()->setVisible(true);
		fileBalance->doBalance();

		slot_setTableHeaders(false);
		slot_updateDisplay(false);
		}
	delete qf;
	}

