// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "Dialogs/mainwindow.h"
#include "Dialogs/archivesdialog.h"
#include "Dialogs/filetypedialog.h"
#include "Dialogs/namesquerydialog.h"
#include "Dialogs/rangequerydialog.h"
#include "Dialogs/simplequerydialog.h"
#include "Dialogs/specialquerydialog.h"
#include "OtherWssi/wssiproto.h"

void MainWindow::slot_showallClicked()
	{
	if(0 == Diskno)
		return;
	if(NoId)
		selectAllExceptIdUnsorted();
	else
		selectAllUnsorted();
	slot_updateDisplay(true);
	}

void MainWindow::slot_closeQueries()
	{
	Q_EMIT signal_close_queries();
	}

void MainWindow::slot_pushButtonArchivesClicked()
	{
	ArchivesQueryDialog *q = new ArchivesQueryDialog(this);
	q->setAttribute(Qt::WA_DeleteOnClose);
	q->show();
	}

void MainWindow::slot_pushButtonFiletypeClicked()
	{
	FiletypeQueryDialog *q = new FiletypeQueryDialog(this);
	q->setAttribute(Qt::WA_DeleteOnClose);
	q->show();
	}

void MainWindow::slot_pushButtonInvertClicked()
	{
	updatePreviouslySelected();
	Noselect = 0;
	for(unsigned long k=0; k<Nofile; k++)
		{
		struct filerec *dr_k = Dr + k;
		dr_k->Bitflags ^= PREVIOUSLY_SELECTED;
		if(dr_k->Bitflags & PREVIOUSLY_SELECTED)
			{
			Sortindx[Noselect] = k;
			Noselect++;
			}
		}
	slot_updateDisplay(true);
	}

void MainWindow::slot_pushButtonKillIdClicked()
	{
	NoId = !NoId;
	hideVolSub(NoId);
	if(NoId)
		{
		slot_updateDisplay(true);
		}
	Q_EMIT signal_hideSettingChanged(NoId);
	}

// If hide is true, remove volume and subdir records from selection but do not update display
// Otherwise do nothing
void MainWindow::hideVolSub(bool hide)
	{
	if(!hide)
		return;
// NoId gets used in wsreject(), save current value, temporarily set to true
	bool noidSave = NoId;
	NoId = true;
	for(int i=0; i<SEL_DIM; i++)
		Usesel[i] = false;
	Nselect = 0;
	Sel[Nselect++] = SEL_FROM_PREVIOUS;
	Usesel[SEL_FROM_PREVIOUS] = true;
	updatePreviouslySelected();
	doSelection();
	NoId = noidSave;
	}

void MainWindow::slot_pushButtonNamesClicked()
	{
	NamesQueryDialog *q = new NamesQueryDialog(this);
	q->setAttribute(Qt::WA_DeleteOnClose);
	q->show();
	}

void MainWindow::slot_pushButtonQueryClicked()
	{
	SimpleQueryDialog *s = new SimpleQueryDialog(this);
	s->setAttribute(Qt::WA_DeleteOnClose);
	s->show();
	}

void MainWindow::slot_pushButtonRangeClicked()
	{
	RangeQueryDialog *r = new RangeQueryDialog(this);
	r->setAttribute(Qt::WA_DeleteOnClose);
	r->show();
	}

void MainWindow::slot_pushButtonSpecialClicked()
	{
	SpecialQueryDialog *q = new SpecialQueryDialog(this);
	q->setAttribute(Qt::WA_DeleteOnClose);
	q->show();
	}
