// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "Dialogs/textviewer.h"
#include "ui_textviewer.h"
#include "Dialogs/mainwindow.h"
#include "OtherWssi/globalsettings.h"
#include "Workarounds/forcecompile.h"
#include "3rdparty/otherversion.h"

#include <QFontDialog>
#include <QSettings>

#define FONTSPAN "<span style=\"font-size: large; font-weight: bold;\">"

void MainWindow::otherLicense()
	{
	textViewer *other = new textViewer(tr("Other licenses"), this);
	other->show();

	QString sheet = QString::fromLatin1("td {padding: 0px 15px;} h3 {text-align: left;}");
	other->ui->tvText->document()->setDefaultStyleSheet(sheet);

	other->ui->tvText->append(tr(
		"<h3 style=\"text-align: center\";>Licenses for packages used by Wssindex</h3><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"https://www.7-zip.org/sdk.html\">7-Zip SDK</a></span> version %1 %2"
		"<p>"
		"LZMA SDK is written and placed in the public domain by Igor Pavlov."
		"<p>"
		"Some code in LZMA SDK is based on public domain code from another developers:"
		"<ol>"
		"<li>PPMd var.H (2001): Dmitry Shkarin"
		"<li>SHA-256: Wei Dai (Crypto++ library)"
		"</ol>"
		"Anyone is free to copy, modify, publish, use, compile, sell, or distribute the "
		"original LZMA SDK code, either in source code form or as a compiled binary, for "
		"any purpose, commercial or non-commercial, and by any means."
		"<p>"
		"LZMA SDK code is compatible with open source licenses, for example, you can "
		"include it to GNU GPL or GNU LGPL code.").arg(ZIP7_VERSION, ZIP7_DATE));

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"https://mediaarea.net/en/MediaInfo\">MediaInfo</a> (Lib)</span> version %1"
		"<p>"
		"Copyright (c) %2 Info@MediaArea.net SARL. All rights reserved."
		"</p>"
		"<p>"
		"Redistribution and use in source and binary forms, with or without modification,"
		" are permitted provided that the following conditions are met:"
		"</p>"
		"<ul>"
		"<li>Redistributions of source code must retain the above copyright notice,"
		" this list of conditions and the following disclaimer."
		"<li>Redistributions in binary form must reproduce the above copyright notice,"
		" this list of conditions and the following disclaimer in the documentation and/or"
		" other materials provided with the distribution."
		"</ul>"
		"<p>"
		"THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS &ldquo;AS IS&rdquo;"
		" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES"
		" OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE"
		" COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,"
		" EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE"
		" GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED"
		" AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING"
		" NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED"
		" OF THE POSSIBILITY OF SUCH DAMAGE.").arg(MEDIAINFO_VERSION, MEDIAINFO_DATE));

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		 FONTSPAN "<a href=\"http://greenfishsoftware.org/\">Greenfish Icon Editor Pro version %1 %2</a>"
		 " (used to create Windows icon)</span>"
		 "<p>"
		 "Open source software for editing icons, cursors and other pixelgraphic images.<br>"
		 "Copyright © 2007-2017 Balázs Szalkai").arg(GREENFISH_VERSION, GREENFISH_DATE));

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"https://www.openssl.org/\">OpenSSL version %1 %2</a>"
		" (used by Wssindex version check and MediaInfo)</span>"
		"<p>"
#ifdef BUILT_WITH_MinGW
		"32-bit Windows binaries are bundled with the MinGW compiler."
#else
		"Windows binaries from <a href=\"https://slproweb.com/products/Win32OpenSSL.html\">slproweb.com</a>"
#endif
		"<p>"
		"Copyright (c) 1998-2015 The OpenSSL Project<br>"
		"Copyright (c) 1995-1998 Eric A. Young, Tim J. Hudson<br>"
		"All rights reserved."
		"<p>"
		"<u>LICENSE ISSUES</u>"
		"<p>"
		"The OpenSSL toolkit stays under a dual license, i.e. both the conditions of"
		" the OpenSSL License and the original SSLeay license apply to the toolkit."
		" See below for the actual license texts. Actually both licenses are BSD-style"
		" Open Source licenses. In case of any license issues related to OpenSSL"
		" please contact openssl-core@openssl.org."
		"<p>"
		"<u>OpenSSL License</u>"
		"<p>"
		"Copyright (c) 1998-2016 The OpenSSL Project.  All rights reserved."
		"<p>"

		"Redistribution and use in source and binary forms, with or without"
		" modification, are permitted provided that the following conditions"
		" are met:"
		"<ol>"
		"<li>Redistributions of source code must retain the above copyright"
		" notice, this list of conditions and the following disclaimer."

		"<li>Redistributions in binary form must reproduce the above copyright"
		" notice, this list of conditions and the following disclaimer in"
		" the documentation and/or other materials provided with the distribution."

		"<li>All advertising materials mentioning features or use of this"
		" software must display the following acknowledgment:"
		" &quot;This product includes software developed by the OpenSSL Project"
		" for use in the OpenSSL Toolkit. (https://www.openssl.org/)&quot;"

		"<li>The names &quot;OpenSSL Toolkit&quot; and &quot;OpenSSL Project&quot; must not be used to"
		" endorse or promote products derived from this software without"
		" prior written permission. For written permission, please contact"
		" openssl-core@openssl.org."

		"<li>Products derived from this software may not be called &quot;OpenSSL&quot;"
		" nor may &quot;OpenSSL&quot; appear in their names without prior written"
		" permission of the OpenSSL Project."

		"<li>Redistributions of any form whatsoever must retain the following acknowledgment:"
		" &quot;This product includes software developed by the OpenSSL Project"
		" for use in the OpenSSL Toolkit (https://www.openssl.org/)&quot;"
		"</ol>"

		"THIS SOFTWARE IS PROVIDED BY THE OpenSSL PROJECT ``AS IS'' AND ANY"
		" EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE"
		" IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR"
		" PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE OpenSSL PROJECT OR"
		" ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,"
		" SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT"
		" NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;"
		" LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)"
		" HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,"
		" STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)"
		" ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED"
		" OF THE POSSIBILITY OF SUCH DAMAGE."
		"<p>"
		"This product includes cryptographic software written by Eric Young"
		" (eay@cryptsoft.com).  This product includes software written by Tim"
		" Hudson (tjh@cryptsoft.com)."
		"<p>"
		"<u>Original SSLeay License</u>"

		"Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)<br>"
		"All rights reserved."
		"<p>"
		"This package is an SSL implementation written"
		" by Eric Young (eay@cryptsoft.com)."
		" The implementation was written so as to conform with Netscapes SSL."
		"<p>"
		"This library is free for commercial and non-commercial use as long as"
		" the following conditions are aheared to.  The following conditions"
		" apply to all code found in this distribution, be it the RC4, RSA,"
		" lhash, DES, etc., code; not just the SSL code.  The SSL documentation"
		" included with this distribution is covered by the same copyright terms"
		" except that the holder is Tim Hudson (tjh@cryptsoft.com)."
		"<p>"
		"Copyright remains Eric Young's, and as such any Copyright notices in"
		" the code are not to be removed."
		" If this package is used in a product, Eric Young should be given attribution"
		" as the author of the parts of the library used."
		" This can be in the form of a textual message at program startup or"
		" in documentation (online or textual) provided with the package."
		"<p>"
		"Redistribution and use in source and binary forms, with or without"
		" modification, are permitted provided that the following conditions"
		" are met:"
		"<ol>"
		"<li>Redistributions of source code must retain the copyright"
		" notice, this list of conditions and the following disclaimer."
		"<li>Redistributions in binary form must reproduce the above copyright"
		" notice, this list of conditions and the following disclaimer in the"
		" documentation and/or other materials provided with the distribution."
		"<li>All advertising materials mentioning features or use of this software"
		" must display the following acknowledgement:<br>"
		"&quot;This product includes cryptographic software written by"
		" Eric Young (eay@cryptsoft.com)"
		" The word 'cryptographic' can be left out if the rouines from the library"
		" being used are not cryptographic related :-)."
		"<li>If you include any Windows specific code (or a derivative thereof) from"
			" the apps directory (application code) you must include an acknowledgement:"
			"&quot;This product includes software written by Tim Hudson (tjh@cryptsoft.com)&quot;"
		"</ol>"
		"THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND"
		" ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE"
		" IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE"
		" ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE"
		" FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL"
		" DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS"
		" OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)"
		" HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT"
		" LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY"
		" OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF"
		" SUCH DAMAGE."

		"The licence and distribution terms for any publically available version or"
		" derivative of this code cannot be changed.  i.e. this code cannot simply be"
		" copied and put under another distribution licence"
		" [including the GNU Public Licence.]")
#ifdef BUILT_WITH_MinGW
				.arg(OPENSSL_MINGW_VERSION).arg(OPENSSL_MINGW_DATE));
#else
				.arg(OPENSSL_VERSION, OPENSSL_DATE));
#endif

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"http://zenlib.sourceforge.net\">ZenLib</a>"
		" (used by MediaInfo)</span> version %1"
		"<p>"
		"Copyright (c) %2 MediaArea.net SARL. All rights reserved."
		"<p>"
		"This software is provided 'as-is', without any express or implied"
		" warranty.  In no event will the authors be held liable for any damages"
		" arising from the use of this software."
		"<p>"
		"Permission is granted to anyone to use this software for any purpose,"
		" including commercial applications, and to alter it and redistribute it"
		" freely, subject to the following restrictions:"
		"<ol>"
		"<li>The origin of this software must not be misrepresented; you must not"
		" claim that you wrote the original software. If you use this software"
		" in a product, an acknowledgment in the product documentation would be"
		" appreciated but is not required."
		"<li>Altered source versions must be plainly marked as such, and must not be"
		" misrepresented as being the original software."
		"<li>This notice may not be removed or altered from any source distribution."
		"</ol><p>").arg(ZENLIB_VERSION, ZENLIB_DATE));
// <p> tag above avoids a Qt bug that would otherwise add an empty item to the list.
// It does add some extra space to the output, a lesser evil.

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"https://zlib.net\">zlib</a>"
		" (used by MediaInfo)</span> version %1<p>"
		"(C) %2 Jean-loup Gailly and Mark Adler"
		"<p>"
		"This software is provided 'as-is', without any express or implied"
		" warranty.  In no event will the authors be held liable for any damages"
		" arising from the use of this software."
		"<p>"
		"Permission is granted to anyone to use this software for any purpose,"
		" including commercial applications, and to alter it and redistribute it"
		" freely, subject to the following restrictions:"
		"<ol>"
		"<li>The origin of this software must not be misrepresented; you must not"
		" claim that you wrote the original software. If you use this software"
		" in a product, an acknowledgment in the product documentation would be"
		" appreciated but is not required."
		"<li>Altered source versions must be plainly marked as such, and must not be"
		"  misrepresented as being the original software."
		"<li>This notice may not be removed or altered from any source distribution."
		"</ol>"
		"<table style=\"float:right\"><tr>"
		"<td>Jean-loup Gailly</td \"><td>Mark Adler</td></tr>"
		"<tr><td>jloup@gzip.org</td><td>madler@alumni.caltech.edu</td></tr></table><p>").arg(ZLIB_VERSION, ZLIB_DATE));

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"https://www.rarlab.com/rar_add.htm\">UnRAR.dll</a></span> %1<p>"
		"The unrar.dll library is freeware. This means:"

		"<ol>"
		"<li>All copyrights to RAR and the unrar.dll are exclusively"
		" owned by the author - Alexander Roshal."

		"<li>The unrar.dll library may be used in any software to handle"
		" RAR archives without limitations free of charge."

		"<li>THE RAR ARCHIVER AND THE UNRAR.DLL LIBRARY ARE DISTRIBUTED &quot;AS IS&quot;."
		" NO WARRANTY OF ANY KIND IS EXPRESSED OR IMPLIED.  YOU USE AT"
		" YOUR OWN RISK. THE AUTHOR WILL NOT BE LIABLE FOR DATA LOSS,"
		" DAMAGES, LOSS OF PROFITS OR ANY OTHER KIND OF LOSS WHILE USING"
		" OR MISUSING THIS SOFTWARE."
		"</ol>"

		"Thank you for your interest in RAR and unrar.dll."

		"<table style=\"float:right\"><tr>"
		"<td>Alexander L. Roshal</td \"></tr><p>").arg(UNRARDLL_DATE));

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"https://www.mimec.org/blog/modern-qt-style-for-windows\">Modern Qt style for Windows</a></span> version %1<p>"
		"Copyright (C) %2 Michał Męciński"
		"<p>"
		"Redistribution and use in source and binary forms, with or without"
		" modification, are permitted provided that the following conditions are met:"
		"<ol>"
		"<li>Redistributions of source code must retain the above copyright notice,"
		" this list of conditions and the following disclaimer."
		"<li>Redistributions in binary form must reproduce the above copyright"
		" notice, this list of conditions and the following disclaimer in the"
		" documentation and/or other materials provided with the distribution."
		"<li>Neither the name of the copyright holder nor the names of the"
		" contributors may be used to endorse or promote products derived from"
		" this software without specific prior written permission."
		"</ol><p>"
		"THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\""
		" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE"
		" IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE"
		" ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE"
		" LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR"
		" CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF"
		" SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS"
		" INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN"
		" CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)"
		" ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE"
		" POSSIBILITY OF SUCH DAMAGE.").arg(MODERNSTYLE_VERSION, MODERNSTYLE_DATE));

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"https://www.qcustomplot.com/\">QCustomPlot</a></span> An easy to use, modern plotting widget for Qt version %1<p>"
		"Copyright (C) %2 Emanuel Eichhammer"
		"<p>"
		"This program is free software: you can redistribute it and/or modify"
		" it under the terms of the GNU General Public License as published by"
		" the Free Software Foundation, either version 3 of the License, or"
		" (at your option) any later version."
		"<p>"
		"This program is distributed in the hope that it will be useful,"
		" but WITHOUT ANY WARRANTY; without even the implied warranty of"
		" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the"
		" GNU General Public License for more details."
		"<p>"
		"You should have received a copy of the GNU General Public License"
		" along with this program.  If not, see https://www.gnu.org/licenses/."
		"<p>"
		"<table>"
		"<tr><td align=\"right\">Author:</td><td>Emanuel Eichhammer</td></tr>"
		"<tr><td align=\"right\">Website/Contact:</td><td><a href=\"https://www.qcustomplot.com/\">https://www.qcustomplot.com/</a></td></tr>"
		"<tr><td align=\"right\">Date:</td><td>%3</td></tr>"
		"<tr><td align=\"right\">Version:</td><td>%1</td></tr>"
		"</table>").arg(QCUSTOMPLOT_VERSION, QCUSTOMPLOT_DATE, QCUSTOMPLOT_RELEASE));

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"http://infozip.sourceforge.net/\">Info-Zip</a></span> unzip version %1<p>"
		"Copyright (c) %2 Info-ZIP.  All rights reserved."
		"<p>"
		"For the purposes of this copyright and license, &quot;Info-ZIP&quot; is defined as"
		" the following set of individuals:"
		"<p>"
		"<blockquote>"
		"   Mark Adler, John Bush, Karl Davis, Harald Denker, Jean-Michel Dubois,"
		"   Jean-loup Gailly, Hunter Goatley, Ed Gordon, Ian Gorman, Chris Herborth,"
		"   Dirk Haase, Greg Hartwig, Robert Heath, Jonathan Hudson, Paul Kienitz,"
		"   David Kirschbaum, Johnny Lee, Onno van der Linden, Igor Mandrichenko,"
		"   Steve P. Miller, Sergio Monesi, Keith Owens, George Petrov, Greg Roelofs,"
		"   Kai Uwe Rommel, Steve Salisbury, Dave Smith, Steven M. Schweda,"
		"   Christian Spieler, Cosmin Truta, Antoine Verheijen, Paul von Behren,"
		"   Rich Wales, Mike White."
		"</blockquote>"
		"<p>"
		"This software is provided &quot;as is,&quot; without warranty of any kind, express"
		" or implied.  In no event shall Info-ZIP or its contributors be held liable"
		" for any direct, indirect, incidental, special or consequential damages"
		" arising out of the use of or inability to use this software."
		"<p>"
		"Permission is granted to anyone to use this software for any purpose,"
		" including commercial applications, and to alter it and redistribute it"
		" freely, subject to the above disclaimer and the following restrictions:"
		"<p>"
		"<ol>"
		"<li>Redistributions of source code (in whole or in part) must retain"
		" the above copyright notice, definition, disclaimer, and this list"
		" of conditions."
		"<li>Redistributions in binary form (compiled executables and libraries)"
		" must reproduce the above copyright notice, definition, disclaimer,"
		" and this list of conditions in documentation and/or other materials"
		" provided with the distribution.  Additional documentation is not needed"
		" for executables where a command line license option provides these and"
		" a note regarding this option is in the executable's startup banner.  The"
		" sole exception to this condition is redistribution of a standard"
		" UnZipSFX binary (including SFXWiz) as part of a self-extracting archive;"
		" that is permitted without inclusion of this license, as long as the"
		" normal SFX banner has not been removed from the binary or disabled."
		"<li>Altered versions--including, but not limited to, ports to new operating"
		" systems, existing ports with new graphical interfaces, versions with"
		" modified or added functionality, and dynamic, shared, or static library"
		" versions not from Info-ZIP--must be plainly marked as such and must not"
		" be misrepresented as being the original source or, if binaries,"
		" compiled from the original source.  Such altered versions also must not"
		" be misrepresented as being Info-ZIP releases--including, but not"
		" limited to, labeling of the altered versions with the names &quot;Info-ZIP&quot;"
		" (or any variation thereof, including, but not limited to, different"
		" capitalizations), &quot;Pocket UnZip,&quot; &quot;WiZ&quot; or &quot;MacZip&quot; without the"
		" explicit permission of Info-ZIP.  Such altered versions are further"
		" prohibited from misrepresentative use of the Zip-Bugs or Info-ZIP"
		" e-mail addresses or the Info-ZIP URL(s), such as to imply Info-ZIP"
		" will provide support for the altered versions."
		"<li>Info-ZIP retains the right to use the names &quot;Info-ZIP,&quot; &quot;Zip,&quot; &quot;UnZip,&quot;"
		" &quot;UnZipSFX,&quot; &quot;WiZ,&quot; &quot;Pocket UnZip,&quot; &quot;Pocket Zip,&quot; and &quot;MacZip&quot; for its"
		" own source and binary releases."
		"</ol><p>").arg(UNZIP_VERSION, UNZIP_DATE));
// <p> tag above avoids a Qt bug that would otherwise add an empty item to the list.

	other->ui->tvText->append(tr("<hr><p>"));

	other->ui->tvText->append(tr(
		FONTSPAN "<a href=\"https://nsis.sourceforge.io/Main_Page\">Nullsoft Scriptable Install System</a></span> version %1<p>"
		"<u>COPYRIGHT</u>"
		"<p>"
		"Copyright (C) 1995-2015 Contributors"
		"<p>"
		"More detailed copyright information can be found in the individual source code files."
		"<p>"
		"<u>APPLICABLE LICENSES</u>"

		"<ul>"

		"<li>All NSIS source code, plug-ins, documentation, examples, header files and graphics,"
		" with the exception of the compression modules and where otherwise noted, are licensed"
		" under the zlib/libpng license."

		"<li>The zlib compression module for NSIS is licensed under the zlib/libpng license."

		"<li>The bzip2 compression module for NSIS is licensed under the bzip2 license."

		"<li>The LZMA compression module for NSIS is licensed under the Common Public License version 1.0."
		"</ul>"

		"<u>ZLIB/LIBPNG LICENSE/<u>"
		"<p>"
		"This software is provided 'as-is', without any express or implied warranty. In no event"
		" will the authors be held liable for any damages arising from the use of this software."
		"<p>"
		"Permission is granted to anyone to use this software for any purpose, including commercial"
		" applications, and to alter it and redistribute it freely, subject to the following"
		" restrictions:"

		"<ol>"

		"<li>The origin of this software must not be misrepresented; you must not claim that you"
		" wrote the original software. If you use this software in a product, an acknowledgment in"
		" the product documentation would be appreciated but is not required."

		"<li>Altered source versions must be plainly marked as such, and must not be misrepresented"
		" as being the original software."

		"<li>This notice may not be removed or altered from any source distribution."
		"</ol>"

		"<u>BZIP2 LICENSE</u>"
		"<p>"
		"This program, &quot;bzip2&quot; and associated library &quot;libbzip2&quot;, are copyright (C) 1996-2000"
		" Julian R Seward. All rights reserved."
		"<p>"
		"Redistribution and use in source and binary forms, with or without modification, are"
		" permitted provided that the following conditions are met:"

		"<ol>"

		"<li>Redistributions of source code must retain the above copyright notice, this list of"
		" conditions and the following disclaimer."

		"<li>The origin of this software must not be misrepresented; you must not claim that you"
		" wrote the original software. If you use this software in a product, an acknowledgment in"
		" the product documentation would be appreciated but is not required."

		"<li>Altered source versions must be plainly marked as such, and must not be misrepresented"
		" as being the original software."

		"<li>The name of the author may not be used to endorse or promote products derived from"
		" this software without specific prior written permission."
		"</ol>"

		"THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,"
		" INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A"
		" PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,"
		" INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT"
		" LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR"
		" BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,"
		" STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF"
		" THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
		"<p>"
		"Julian Seward, Cambridge, UK."
		"<p>"
		"jseward@acm.org"
		"<p>"
		"<u>COMMON PUBLIC LICENSE VERSION 1.0</u>"
		"<p>"
		"THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON PUBLIC LICENSE"
		" (&quot;AGREEMENT&quot;). ANY USE, REPRODUCTION OR DISTRIBUTION OF THE PROGRAM CONSTITUTES"
		" RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT."

		"<ol>"
		"<li>DEFINITIONS"
		"<p>"
		"&quot;Contribution&quot; means:<br>"

		"a) in the case of the initial Contributor, the initial code and documentation"
		" distributed under this Agreement, and<br>"

		"b) in the case of each subsequent Contributor:<br>"

		"i) changes to the Program, and<br>"

		"ii) additions to the Program;"
		"<p>"
		"where such changes and/or additions to the Program originate from and are"
		" distributed by that particular Contributor. A Contribution 'originates' from a"
		" Contributor if it was added to the Program by such Contributor itself or anyone"
		" acting on such Contributor's behalf. Contributions do not include additions to the"
		" Program which: (i) are separate modules of software distributed in conjunction with"
		" the Program under their own license agreement, and (ii) are not derivative works of"
		" the Program."
		"<p>"
		"&quot;Contributor&quot; means any person or entity that distributes the Program."
		"<p>"
		"&quot;Licensed Patents &quot; mean patent claims licensable by a Contributor which are"
		" necessarily infringed by the use or sale of its Contribution alone or when combined with"
		" the Program."
		"<p>"
		"&quot;Program&quot; means the Contributions distributed in accordance with this Agreement."
		"<p>"
		"&quot;Recipient&quot; means anyone who receives the Program under this Agreement,"
		" including all Contributors."

		"<li>GRANT OF RIGHTS"
		"<p><ol type='a'>"

		"<li>Subject to the terms of this Agreement, each Contributor hereby grants Recipient a"
		" non-exclusive, worldwide, royalty-free copyright license to reproduce, prepare derivative"
		" works of, publicly display, publicly perform, distribute and sublicense the Contribution"
		" of such Contributor, if any, and such derivative works, in source code and object code"
		" form."

		"<li>Subject to the terms of this Agreement, each Contributor hereby grants Recipient a"
		" non-exclusive, worldwide, royalty-free patent license under Licensed Patents to make, use,"
		" sell, offer to sell, import and otherwise transfer the Contribution of such Contributor,"
		" if any, in source code and object code form. This patent license shall apply to the"
		" combination of the Contribution and the Program if, at the time the Contribution is added"
		" by the Contributor, such addition of the Contribution causes such combination to be"
		" covered by the Licensed Patents. The patent license shall not apply to any other"
		" combinations which include the Contribution. No hardware per se is licensed hereunder."

		"<li>Recipient understands that although each Contributor grants the licenses to its"
		" Contributions set forth herein, no assurances are provided by any Contributor that the"
		" Program does not infringe the patent or other intellectual property rights of any other"
		" entity. Each Contributor disclaims any liability to Recipient for claims brought by any"
		" other entity based on infringement of intellectual property rights or otherwise. As a"
		" condition to exercising the rights and licenses granted hereunder, each Recipient hereby"
		" assumes sole responsibility to secure any other intellectual property rights needed, if"
		" any. For example, if a third party patent license is required to allow Recipient to"
		" distribute the Program, it is Recipient's responsibility to acquire that license before"
		" distributing the Program."

		"<li>Each Contributor represents that to its knowledge it has sufficient copyright rights"
		" in its Contribution, if any, to grant the copyright license set forth in this Agreement."
		"</ol>"
		"<p>"
		"<li>REQUIREMENTS<p>"
		"A Contributor may choose to distribute the Program in object code form under its own"
		" license agreement, provided that:"

		"<ol type='a'>"
		"<li>it complies with the terms and conditions of this Agreement; and"

		"<li>its license agreement:"
		"<ol type='i'>"

		"<li>effectively disclaims on behalf of all Contributors all warranties and conditions,"
		" express and implied, including warranties or conditions of title and non-infringement, and"
		" implied warranties or conditions of merchantability and fitness for a particular purpose;"

		"<li>effectively excludes on behalf of all Contributors all liability for damages,"
		" including direct, indirect, special, incidental and consequential damages, such as lost"
		" profits;"

		"<li>states that any provisions which differ from this Agreement are offered by that"
		" Contributor alone and not by any other party; and"

		"<li>states that source code for the Program is available from such Contributor, and"
		" informs licensees how to obtain it in a reasonable manner on or through a medium"
		" customarily used for software exchange."
		"</ol>"

		"When the Program is made available in source code form:"
		"<ol type='a'>"

		"<li>it must be made available under this Agreement; and"

		"<li>a copy of this Agreement must be included with each copy of the Program."
		"</ol></ol><p>"

		"Contributors may not remove or alter any copyright notices contained within the Program."
		"<p>"
		"Each Contributor must identify itself as the originator of its Contribution, if any, in a"
		" manner that reasonably allows subsequent Recipients to identify the originator of the"
		" Contribution."

		"<li>COMMERCIAL DISTRIBUTION"
		"<p>"
		"Commercial distributors of software may accept certain responsibilities with respect to"
		" end users, business partners and the like. While this license is intended to facilitate"
		" the commercial use of the Program, the Contributor who includes the Program in a"
		" commercial product offering should do so in a manner which does not create potential"
		" liability for other Contributors. Therefore, if a Contributor includes the Program in a"
		" commercial product offering, such Contributor (&quot;Commercial Contributor&quot;) hereby"
		" agrees to defend and indemnify every other Contributor (&quot;Indemnified"
		" Contributor&quot;) against any losses, damages and costs (collectively &quot;Losses&quot;)"
		" arising from claims, lawsuits and other legal actions brought by a third party against the"
		" Indemnified Contributor to the extent caused by the acts or omissions of such Commercial"
		" Contributor in connection with its distribution of the Program in a commercial product"
		" offering. The obligations in this section do not apply to any claims or Losses relating to"
		" any actual or alleged intellectual property infringement. In order to qualify, an"
		" Indemnified Contributor must: a) promptly notify the Commercial Contributor in writing of"
		" such claim, and b) allow the Commercial Contributor to control, and cooperate with the"
		" Commercial Contributor in, the defense and any related settlement negotiations. The"
		" Indemnified Contributor may participate in any such claim at its own expense."
		"<p>"
		" For example, a Contributor might include the Program in a commercial product offering,"
		" Product X. That Contributor is then a Commercial Contributor. If that Commercial"
		" Contributor then makes performance claims, or offers warranties related to Product X,"
		" those performance claims and warranties are such Commercial Contributor's responsibility"
		" alone. Under this section, the Commercial Contributor would have to defend claims against"
		" the other Contributors related to those performance claims and warranties, and if a court"
		" requires any other Contributor to pay any damages as a result, the Commercial Contributor"
		" must pay those damages."

		"<li>NO WARRANTY"
		"<p>"
		"EXCEPT AS EXPRESSLY SET FORTH IN THIS AGREEMENT, THE PROGRAM IS PROVIDED ON AN &quot;AS"
		" IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED"
		" INCLUDING, WITHOUT LIMITATION, ANY WARRANTIES OR CONDITIONS OF TITLE, NON-INFRINGEMENT,"
		" MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Each Recipient is solely responsible"
		" for determining the appropriateness of using and distributing the Program and assumes all"
		" risks associated with its exercise of rights under this Agreement, including but not"
		" limited to the risks and costs of program errors, compliance with applicable laws, damage"
		" to or loss of data, programs or equipment, and unavailability or interruption of"
		" operations."

		"<li>DISCLAIMER OF LIABILITY"
		"<p>"
		"EXCEPT AS EXPRESSLY SET FORTH IN THIS AGREEMENT, NEITHER RECIPIENT NOR ANY CONTRIBUTORS"
		" SHALL HAVE ANY LIABILITY FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR"
		" CONSEQUENTIAL DAMAGES (INCLUDING WITHOUT LIMITATION LOST PROFITS), HOWEVER CAUSED AND ON"
		" ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING"
		" NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OR DISTRIBUTION OF THE PROGRAM"
		" OR THE EXERCISE OF ANY RIGHTS GRANTED HEREUNDER, EVEN IF ADVISED OF THE POSSIBILITY OF"
		" SUCH DAMAGES."

		"<li>GENERAL"
		"<p>"
		"If any provision of this Agreement is invalid or unenforceable under applicable law, it"
		" shall not affect the validity or enforceability of the remainder of the terms of this"
		" Agreement, and without further action by the parties hereto, such provision shall be"
		" reformed to the minimum extent necessary to make such provision valid and enforceable."
		"<p>"
		"If Recipient institutes patent litigation against a Contributor with respect to a patent"
		" applicable to software (including a cross-claim or counterclaim in a lawsuit), then any"
		" patent licenses granted by that Contributor to such Recipient under this Agreement shall"
		" terminate as of the date such litigation is filed. In addition, if Recipient institutes"
		" patent litigation against any entity (including a cross-claim or counterclaim in a"
		" lawsuit) alleging that the Program itself (excluding combinations of the Program with"
		" other software or hardware) infringes such Recipient's patent(s), then such Recipient's"
		" rights granted under Section 2(b) shall terminate as of the date such litigation is filed."
		"<p>"
		"All Recipient's rights under this Agreement shall terminate if it fails to comply with any"
		" of the material terms or conditions of this Agreement and does not cure such failure in a"
		" reasonable period of time after becoming aware of such noncompliance. If all Recipient's"
		" rights under this Agreement terminate, Recipient agrees to cease use and distribution of"
		" the Program as soon as reasonably practicable. However, Recipient's obligations under this"
		" Agreement and any licenses granted by Recipient relating to the Program shall continue and"
		" survive."
		"<p>"
		"Everyone is permitted to copy and distribute copies of this Agreement, but in order to"
		" avoid inconsistency the Agreement is copyrighted and may only be modified in the following"
		" manner. The Agreement Steward reserves the right to publish new versions (including"
		" revisions) of this Agreement from time to time. No one other than the Agreement Steward"
		" has the right to modify this Agreement. IBM is the initial Agreement Steward. IBM may"
		" assign the responsibility to serve as the Agreement Steward to a suitable separate"
		" entity. Each new version of the Agreement will be given a distinguishing version"
		" number. The Program (including Contributions) may always be distributed subject to the"
		" version of the Agreement under which it was received. In addition, after a new version of"
		" the Agreement is published, Contributor may elect to distribute the Program (including its"
		" Contributions) under the new version. Except as expressly stated in Sections 2(a) and 2(b)"
		" above, Recipient receives no rights or licenses to the intellectual property of any"
		" Contributor under this Agreement, whether expressly, by implication, estoppel or"
		" otherwise. All rights in the Program not expressly granted under this Agreement are"
		" reserved."
		"<p>"
		"This Agreement is governed by the laws of the State of New York and the intellectual"
		" property laws of the United States of America. No party to this Agreement will bring a"
		" legal action under this Agreement more than one year after the cause of action arose. Each"
		" party waives its rights to a jury trial in any resulting litigation."
		"</ol>"

		"<u>SPECIAL EXCEPTION FOR LZMA COMPRESSION MODULE</u>"
		"<p>"
		"Igor Pavlov and Amir Szekely, the authors of the LZMA compression module for NSIS,"
		" expressly permit you to statically or dynamically link your code (or bind by name) to the"
		" files from the LZMA compression module for NSIS without subjecting your linked code to the"
		" terms of the Common Public license version 1.0. Any modifications or additions to files"
		" from the LZMA compression module for NSIS, however, are subject to the terms of the Common"
		" Public License version 1.0.").arg(NSIS_VERSION));
	other->scrollTop();
	}
