// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "Dialogs/textviewer.h"
#include "ui_textviewer.h"
#include "Dialogs/mainwindow.h"
#include "OtherWssi/globalsettings.h"
#include "OtherWssi/wssiproto.h"

#include <QFontDialog>
#include <QSettings>

textViewer::textViewer(QString title, QWidget *parent) : QMainWindow(parent), ui(new Ui::textViewer)
	{
	ui->setupUi(this);
	this->setAttribute(Qt::WA_DeleteOnClose);
	this->setWindowModality(Qt::WindowModal);
	this->setWindowFlags(MyWindowFlags);
	*FontTv = ui->tvText->font();

	ui->tvText->setOpenExternalLinks(true);
	this->setWindowTitle(title);
	restoreSettings();
	connect(ui->pushButton_closeTextViewer, SIGNAL(released()), this, SLOT(slot_closeClicked()));
	connect(ui->pushButton_textFont, SIGNAL(released()), this, SLOT(slot_fontClicked()));
	}

textViewer::~textViewer()
	{
	delete ui;
	}

// Scroll the view to the top of the displayed text
void textViewer::scrollTop()
	{
	ui->tvText->moveCursor(QTextCursor::Start);
	ui->tvText->ensureCursorVisible();
	}

void textViewer::slot_closeClicked()
	{
	slot_saveSettings();
	this->close();
	}

void textViewer::slot_saveSettings()
	{
	QSettings settings("WSS-DDC", "Wssindex\\Geometry");
	settings.setValue("TvGeometryPos", pos());
	settings.setValue("TvGeometrySize", size());

	QSettings options("WSS-DDC", "Wssindex\\Options");
	options.setValue("FontTv", *FontTv);
	}

void textViewer::restoreSettings()
	{
	QSettings options("WSS-DDC", "Wssindex\\Options");
	if(options.contains("FontTv"))
		{
		FontTv->fromString(options.value("FontTv").toString());
		ui->tvText->setFont(*FontTv);
		}

	QSettings settings("WSS-DDC", "Wssindex\\Geometry");
	if(settings.contains("TvGeometrySize"))
		{
		QSize size = settings.value("TvGeometrySize").toSize();
		resize(size);
		}
	if(settings.contains("TvGeometryPos"))
		{
		QPoint pos = settings.value("TvGeometryPos").toPoint();
		move(pos);
		forceOnscreen(this);
		}
	}

void textViewer::slot_fontClicked()
	{
	bool ok;
	QFont font = QFontDialog::getFont(&ok, *FontTv);
	if(ok)
		{
		*FontTv = font;
		ui->tvText->setFont(*FontTv);
		}
	}
