// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "Dialogs/textviewer.h"
#include "ui_textviewer.h"
#include "Dialogs/mainwindow.h"
#include "OtherWssi/globalsettings.h"

void MainWindow::welcomeWindow()
	{
	textViewer *welcome = new textViewer(tr("Welcome"), this);
	welcome->show();

	welcome->ui->tvText->append(tr("<html><head/><body><p>Welcome to Wssindex. Here are a few tips to get you started:<ul>"

			"<li>Wssindex creates a memory-resident database of file information from a collection of disks. In ancient times, floppy disks "
			"were the thing most commonly indexed, but today burned CDs and DVDs, internal, external or network hard disks and memory keys are more likely targets."

			"<li>Perhaps the first thing you should do is set the main window size and position.  Dialogs and the main window will remember "
			"size and position unless they are closed with the \"X\" in the upper right hand corner."

			"<li>Wssindex can extract information from various file types which will appear in either the Comments or Extra Info fields. "
			"You can also edit this information or assign Categories; just double-click on the field to be edited. "
			"Extracting info from files will increase the indexing time required. When reindexing a disk, previously extracted information "
			"can be preserved or discarded."

			"<li>A log window is opened during indexing to show errors and warnings. When extracting information from files, it's not uncommon "
			"to see files that are not the type expected based on their extension, and Wssindex may fail to recognize some valid files. "
			"Wssindex is very picky about the tags in mp3 files while players will usually ignore any errors. Feel free to ignore any errors "
			"seen in the log, or you can save it if you want to go back and examine the files that triggered messages."

			"<li>Many items in settings will show pop-up help if you hover the mouse over them."

			"<li>If the number of files selected for display is large, the display may be split up into pages. The number of files per page is "
			"configurable up to one million. There are some technical reasons why the number can't be arbitrarily large, and in any case, if "
			"you're scrolling through this many files looking for something, you should be doing a query instead."

			"<li>Wsindex philosophy for queries is that simple is best. Complex queries are done by repeated queries adding to or selecting "
			"from the previous results."

			"<li>Sorts are \"stable\". For example, this means that if you sort by time stamp and then again by file name, times will still be "
			"in order for duplicate file names."

			"<li>Keeping the database in memory is good for performance, but not so good if you manage to crash the program before the database "
			"is saved. Wssindex is pretty robust against errors during indexing, but saving the database occassionally is recommended."

			"<li>This tips screen will only be shown automatically the first time you run Wssindex. It's available on the help menu if "
			"you want to display it again."

			"<li>This tips screen is a new feature so there's not much here yet. Want to suggest more tips? Leave suggestions at our "
			"<a href=\"https://wssddc.com/smf/index.php\">online forum</a>."

		"</ul></p></body></html>"));

// This code to increase the spacing between list elements is derived from
// http://www.qtforum.org/article/32901/double-spacing-changing-line-height-in-qtextedit.html
// Link is broken, don't know an alternative.
	for(QTextBlock block = welcome->ui->tvText->document()->begin(); block.isValid(); block = block.next())
		{
		QTextCursor tc = QTextCursor(block);
		QTextBlockFormat fmt = block.blockFormat();
		fmt.setBottomMargin(10);
		tc.setBlockFormat(fmt);
		}

	welcome->scrollTop();
	}
