// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "OtherWssi/globalsettings.h"
#include "OtherWssi/wssiproto.h"
#include "OtherWssi/wsxxxadd.h"
#include "Dialogs/indexwindow.h"
#include "Dialogs/mainwindow.h"

#include <string>
#include <iostream>
#include <sstream>
#include <iomanip>

#include "MediaInfo/MediaInfo.h"
#include "ZenLib/Ztring.h"

using namespace MediaInfoLib;
using namespace ZenLib;

int IndexWindow::mediaInfoVideoAdd(QString path, QString filename, int /* mode */)
	{
	if(skip_extract(filename))
		return(SKIPPED);

	int return_code = EXTRACTED_OK;

	MediaInfo MI;
	QString name_with_path = path;
	name_with_path += filename;

	if(!MI.Open(name_with_path.toStdWString()))
		return(CANT_OPEN);

	Ztring durationMsecStr = MI.Get(Stream_General, 0, __T("Duration"), Info_Text);
	double runSeconds = static_cast<double>(durationMsecStr.To_int64s())/1000.;
	int runHours = static_cast<int>(runSeconds/3600.);
	runSeconds -= 3600.*runHours;
	int runMinutes = static_cast<int>(runSeconds/60.);
	runSeconds -= 60.*runMinutes;

	Ztring widthStr = MI.Get(Stream_Video, 0, __T("Width"), Info_Text);
	int width = widthStr.To_int32s();

	Ztring heightStr = MI.Get(Stream_Video, 0, __T("Height"), Info_Text);
	int height = heightStr.To_int32s();
	MI.Close();

	struct filerec *dr_nofile = Dr + Nofile - 1;
	std::stringstream ss;
#define TEMPBUF_SIZE 256
	char tempbuf[TEMPBUF_SIZE];
// If size detection fails, width/height will be zero
	if(width > 0)
		ss << width;
	else
		ss << "?";
	ss << "x";
	if(height > 0)
		ss << height;
	else
		ss << "?";
	ss << ", " << runHours << ":" << std::setfill('0') << std::setw(2) << runMinutes
		<< ":" << std::setfill('0') << std::setw(2) << std::fixed << std::setprecision(0) << runSeconds;
	strncpy_s(tempbuf, TEMPBUF_SIZE, ss.str().c_str(), TEMPBUF_SIZE-1);
	if(extra_arch(tempbuf, dr_nofile, Max_extra_length))
		{
		return_code = DATABASE_FULL;
		Stop_indexing = true;
		QMessageBox::critical(this, tr("Error"), tr("Out of memory in mediaInfoVideoAdd"));
		}
	return(return_code);
	}
