// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "OtherWssi/wssiproto.h"
#include "OtherWssi/wsxxxadd.h"
#include "Dialogs/indexwindow.h"

// pngadd - read a .PNG file and add information to wssindex database.
//	The image size and number of colors are converted into extra info
//	of the form WIDTHxHEIGHTxNCOLORS, plus monochrome if all colors in
//	color table have equal RGB components.

#define PNG_START ("\211" "PNG\r\n" "\032" "\n\0\0\0" "\015" "IHDR")

int IndexWindow::pngadd(QString path, QString filename, int /* dummy */)
	{
#pragma pack(2)
	struct png
		{
		char header[16];
		long width;						// byte order reversed
		long height;					// byte order reversed
		char bit_depth;
		char color_type;
		} png_header;

	unsigned long basefile;
	int bits, return_code;
	bool gray_scale;
	struct filerec *dr_nofile;
	FILE *fp;

	if(skip_extract(filename))
		return(SKIPPED);

	basefile = Nofile - 1;
	return_code = EXTRACTED_OK;

	if(nullptr == (fp = arc_open(path, filename)))
		return(CANT_OPEN);

	if(1 != fread(&png_header, sizeof(struct png), 1, fp)
		|| 0 != strncmp(png_header.header, PNG_START, 16))
		{
		goto corrupt;			// this isn't an error, just a warning
		}

	swap4(&png_header.width);
	swap4(&png_header.height);
	dr_nofile = Dr + basefile;
	gray_scale = false;
	bits = png_header.bit_depth;
	switch(png_header.color_type)
		{
		case 0:
		case 4:
			gray_scale = true;
			break;
		case 2:
		case 6:
			bits *= 3;
			break;
		case 3:
			break;
		}
	dr_nofile->ExtraInfo = tr("%1x%2x%3").arg(png_header.width).arg(png_header.height).arg(num_color_str(bits));

	if(gray_scale)
		dr_nofile->ExtraInfo += tr(", grayscale");
	setHasExtra(dr_nofile);

norm_ret:
		fclose(fp);
		return(return_code);

corrupt:
		return_code = CORRUPT;
		Q_EMIT signal_logMessage(tr("%1%2 is corrupted or not a PNG image.")
				.arg(path, filename));
		goto norm_ret;
	}
