// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef FILETABLEMODEL_H
#define FILETABLEMODEL_H

#include "OtherWssi/wssindex.h"

#include <QAbstractTableModel>

class fileTableModel : public QAbstractTableModel
	{
	Q_OBJECT
public:
	explicit fileTableModel(QObject *parent = nullptr);
	int rowCount(const QModelIndex &parent = QModelIndex()) const override;
	int columnCount(const QModelIndex &parent = QModelIndex()) const override;
	QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
	void refreshData();
	void setSizeAndValidity(int rows, int cols, unsigned long file_start);
	void signalLayoutChanged();
	void setFields();
	void setFileModelValidity(bool isvalid);
	QVariant headerData(int section, Qt::Orientation orientation, int role=Qt::DisplayRole) const override;
	Qt::ItemFlags flags(const QModelIndex &index) const override;
	bool setHeaderData(int section, Qt::Orientation orientation,
		const QVariant &value, int role = Qt::DisplayRole) override;
	bool setData(const QModelIndex & index, const QVariant & value, int role) override;

private:
	bool fileModelValid;
	unsigned long firstFile;
	int displayRows;
	long modelRows;
	int modelCols;
	int fieldNumber[4][NFIELDS];
	QString theader[NFIELDS];

Q_SIGNALS:
	void signal_fileEditCompleted(QModelIndex, QString);

	};

#endif // FILETABLEMODEL_H
