// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "ModelView/volcombomodel.h"
#include "OtherWssi/wssindex.h"
#include "OtherWssi/wssiproto.h"
#include "Dialogs/mainwindow.h"

volComboModel::volComboModel()
	{
// This gets executed before there are any database entries, so pick a
// number of disks that may not require later reallocation.
	volmax = 1000;
	vptr = new unsigned long[volmax];
	diskListValid = false;
	}

volComboModel::~volComboModel()
	{
	delete vptr;
	}

QModelIndex volComboModel::index(int row, int column, const QModelIndex & /*parent */) const
	{
	return createIndex(row, column);
	}

QModelIndex volComboModel::parent(const QModelIndex & /*index */) const
	{
	return QModelIndex();
	}

int volComboModel::rowCount(const QModelIndex & /* parent */) const
	{
	return static_cast<int>(Diskno);
	}

int volComboModel::columnCount(const QModelIndex & /* parent */) const
	{
	return 1;
	}

QVariant volComboModel::data(const QModelIndex &index, int role) const
	{
	if(0 == Diskno)
		return QVariant();
	if(!diskListValid)
		return QVariant();
	switch(role)
		{
		case Qt::DisplayRole:
		case Qt::EditRole:
			return Vrec[vptr[index.row()]].VolName;
		default:
			break;
		}
	return QVariant();
	}

// This is called from the showPopup routine of DiskBox (derived from QComboBox)
// Without the ResetModel calls, the number of items in the pulldown doesn't
// get adjusted when Diskno changes.
void volComboModel::sortDisksIfNeeded()
	{
	beginResetModel();
	if(!diskListValid)
		{
		if(Diskno > volmax)
			{
			delete [] vptr;
			volmax = Diskno + 100;
			vptr = new unsigned long[volmax];
			}
		Vsrtkey = 1;
		Vsrtdir = 1;
		unsigned long *tptr = vptr;
		for(unsigned long i=0; i<Diskno; i++)
			*(tptr++) = i;
		mainWindowPtr->doSort(vptr, Diskno, wssvcomp, 0);
		diskListValid = true;
		}
	endResetModel();
	}
