// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include <QString>
#include <QObject>

// Format a file or volume size as bytes or kilo/mega/giga/tera bytes
// K/M/G/T can be powers of 1000 or 1024
// Truncate results, e.g., 49999 becomes 40 KB (binary or decimal)
// Switch to next suffix occurs at 10 K/M/G/T so this routine will
// never return values in the range 0-9 KB, MB, GB, TB
QString formattedsize(quint64 size, int format)
	{
	switch(format)
		{
		case 0:	// bytes
			break;
		case 1:	// decimal K/M/G/TB
			if(size < Q_INT64_C(10000))
				return QObject::tr("%L1").arg(size);
			if(size < Q_INT64_C(4000000))
				return QObject::tr("%L1 KB").arg(size/Q_INT64_C(1000));
			if(size < Q_INT64_C(10000000000))
				return QObject::tr("%L1 MB").arg(size/Q_INT64_C(1000000));
			if(size < Q_INT64_C(10000000000000))
				return QObject::tr("%L1 GB").arg(size/Q_INT64_C(1000000000));
			return QObject::tr("%L1 TB").arg(size/Q_INT64_C(1000000000000));
		case 2:	// binary K/M/G/TB
			if(size < Q_INT64_C(10240))
				return QObject::tr("%L1").arg(size);
			if(size < Q_INT64_C(10485760))										// 10*1024*1024
				return QObject::tr("%L1 KB").arg(size/Q_INT64_C(1024));
			if(size < Q_INT64_C(10737418240))									// 10*1024*1024*1024
				return QObject::tr("%L1 MB").arg(size/Q_INT64_C(1048576));	// 1024*2024
			if(size < Q_INT64_C(10995116277760))									// 10*1024*1024*1024*1024
				return QObject::tr("%L1 GB").arg(size/Q_INT64_C(1073741824));	// 1024*2024*1024
			return QObject::tr("%L1 TB").arg(size/Q_INT64_C(1099511627776));	// 1024*1024*1024*1024
		default:
			break;
		}
	return QObject::tr("%L1").arg(size);
	}
