// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef GLOBALSETTINGS_H
#define GLOBALSETTINGS_H

// All saved settings except window size/position, info extraction
// options and table design parameters should be in this include file.

#include <QColor>
#include <QFont>

#ifndef EXTERN
	#define EXTERN extern
#endif

#define UNIT_BYTES	0
#define UNIT_DECIMAL	1
#define UNIT_BINARY	2

// *************** Values starting here are saved when configuration is saved
// These names are used in the saved settings, so don't change them
// once they have appeared in a release version
EXTERN bool
	Always_diz_contents,	// always use file_id.diz contents (if extracted)
								// even if another comment is available
	Copy_across_subdirs,
	DateOnly,				// Display only date (not time)
	EjectAfterIndexing,
	FileUseAltColors,
	HelpMenuRight,			// If true, help menu is right justified
	Ignore_arc_ext,
	Ignore_case_sort,		// if true, sorts are case-insensitive
	Index_hidden,			// if true, hidden and system files are included in index
	IndexTimeDirExclude,	// true if index-time directory excludes are to be applied
	IndexTimeDirInclude,	// If true, any index-time directory includes override excludes
	IndexTimeFiltering,	// true if index-time filtering is to be applied
	IndexTimeFileExclude,// true if index-time file excludes are to be applied
	IndexTimeFileInclude,// If true, any index-time file includes override excludes
	Makebak,					// if true, make backup with .bak extension when saving
	Msglog_linewrap,		// if true, linewrap in message log
	NaturalSort,			// if true, sort numbers (as text) in natural order
	Query_extract,			// ask before extracting info from archive files
	Skip_NTFS_mounted,	// skip mounted volumes and other NTFS parse points
	Store_arc_path,		// store name with path for files in archives
	Store_relative_path,	// store relative path when using index starting dir
	UseModernStyle,		// use windows modern style
	UseSystemScale,		// scale everything if system scale is not 100%, restart needed if changed
	VolUseAltColors;

EXTERN char
	Indexing_drive_letter[2];

EXTERN int
	Case_option_indexing,
	disksize_unit,
	Extract_diz,			// where to assign comments from FILE_ID.DIZ, 0=nowhere,
								// 1=to file_id.diz, 2=to zip file
	Fade_time,
	ToolTipFontSize,
	StatusBarFontSize,
	File_row_height,
	Filesize_unit,
	Indent_members,
	Max_bunch,
	Max_category_length,	// longest category allowed
	Max_comment_length,	// longest comment, either entered by user or extracted
	Max_extra_length,		// longest extra info allowed
	Maxdisks_increment,	// amount to increase Maxdisks when reallocation is needed
	Maxfiles_increment,	// amount to increase Maxfiles when reallocation is needed
	Maxsubs_increment,	// amount to increase Maxsubs when reallocation is needed
	Maxdisks_initial,
	Maxfiles_initial,
	Maxsubs_initial,
	Max_threads,
	NrecentDirs,
	NrecentFiles,
	Vol_row_height;

EXTERN unsigned int
	Next_serial_number;

EXTERN QColor
	FileRowColor[2],
	FileGridColor,
	VolGridColor,
	VolRowColor[2],
	UpdatedColor;	// Currently not user setable. Perhaps should have file and vol variants

EXTERN QFont
	*Font_filelist,
	*FontTv,
	*Font_vollist;

EXTERN QString
	Serialization_format;

EXTERN QStringList
	IndexDirExcludeList,
	IndexDirIncludeList,
	IndexFileExcludeList,
	IndexFileIncludeList;

enum ExtractOpts {EXTRACT_NONE=0, EXTRACT_CONFIGURED, EXTRACT_ALL};
EXTERN ExtractOpts
	Extract_opt;

// **************** End of values saved as part of configuration

// **************** Values starting here are saved only for duration of current run
EXTERN QString
	IndexStartingDir;

enum VolnameOpts {VOLNAME_TRUE=0, VOLNAME_PROMPT, VOLNAME_GENERATE};
EXTERN VolnameOpts
		VolnameOpt;

#endif // GLOBALSETTINGS_H
