// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef PINMENU_H
#define PINMENU_H

#include <QWidgetAction>
#include <QHBoxLayout>
#include <QPushButton>
#include "3rdparty/clickablelabel.h"

class PinMenuItem : public QWidgetAction
	{
	Q_OBJECT
public:
	PinMenuItem(QMenu *parent, int id, bool pinstate = false, const QString& title = "");
	~PinMenuItem() override;
	bool isPinned();
	bool togglePin();
	void setPinState(bool pin);
	void setText(const QString &newtitle);

private:
	bool eventFilter(QObject *obj, QEvent *event) override;

public:
	QWidget *pinWidget;

private:
	int idno;
	bool pinned;
	ClickableLabel *pinImage;
	ClickableLabel *pinTitle;
	QHBoxLayout *pinLayout;
	QPixmap pinmap;
	QPixmap unpinmap;
	QMenu *containingMenu;
	QColor defaultBackground;
	QColor highlightBackground;
	QRgb defaultText;
	QRgb highlightText;

private Q_SLOTS:
	void slot_textClicked();
	void slot_pinClicked();

public Q_SLOTS:
	void slot_hovered();
	void slot_unhovered();
	void slot_focusChanged(bool in);

Q_SIGNALS:
	void signal_textClicked(int);
	void signal_pinClicked(int);
	void signal_entered();
	};

#endif // PINMENU_H
