// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "Dialogs/mainwindow.h"
#include "OtherWssi/globalsettings.h"

void MainWindow::setDefaultValues()
	{
// Set default values before loading settings
	Always_diz_contents = false;
	Copy_across_subdirs = false;
	EjectAfterIndexing = true;
	FileUseAltColors = true;
	Ignore_arc_ext = false;
	Ignore_case_sort = true;
	Makebak = true;
	Msglog_linewrap = true;
	Query_extract = false;
	Skip_NTFS_mounted = true;
	UseModernStyle = true;
	VolUseAltColors = true;
	Store_relative_path = false;
	Store_arc_path = false;
	IndexTimeFiltering = false;
	IndexTimeDirExclude = false;
	IndexTimeDirInclude = false;
	IndexTimeFileExclude = false;
	IndexTimeFileInclude = false;
	HelpMenuRight = false;
	MessageLogWindowOpen = false;
	UseSystemScale = true;

	Indexing_drive_letter[0] = 'A';
	Indexing_drive_letter[1] = 'B';

	Case_option_indexing = CASE_PRESERVE;
	Extract_diz = DIZ_ZIP;
	File_row_height = 25;
	Indent_members = 5;
	Vol_row_height = 25;
	ToolTipFontSize = 15;
	StatusBarFontSize = 15	;

	disksize_unit = UNIT_BYTES;
	Filesize_unit = UNIT_BYTES;
	Fade_time = 2;
// Use 1 if number of cores cannot be determined
	Max_threads = qMax(1, QThread::idealThreadCount());
	NrecentDirs = 4;
	NrecentFiles = 4;
	Max_bunch = 100000;

	Maxfiles_initial = 500000;
	Maxsubs_initial  = 50000;
	Maxdisks_initial = 5000;
	Maxfiles_increment = 100000;
	Maxsubs_increment = 10000;
	Maxdisks_increment = 1000;

	Max_category_length = 64;
	Max_comment_length = 64;
	Max_extra_length = 64;

// Default to some light colors, not dull B&W
	FileRowColor[0] = VolRowColor[0] = QColor(255,250,220);
	FileRowColor[1] = VolRowColor[1] = QColor(193,206,250);
	UpdatedColor = Qt::red;
	FileGridColor = Qt::lightGray;
	VolGridColor = Qt::lightGray;

	Extract_opt = EXTRACT_CONFIGURED;
	VolnameOpt = VOLNAME_TRUE;
	layout_default();
	Font_filelist = new QFont();
	Font_vollist = new QFont();
	FontTv = new QFont();
	}

// Convert pulldown index 0-2 to alignment enum
Qt::AlignmentFlag MainWindow::justEnumFromInt(int flag)
	{
	int rc;
	switch(flag)
		{
		default:
		case 0:
			rc = Qt::AlignLeft | Qt::AlignVCenter;
			break;
		case 1:
			rc = Qt::AlignHCenter | Qt::AlignVCenter;
			break;
		case 2:
			rc = Qt::AlignRight | Qt::AlignVCenter;
			break;
		}
	return static_cast<Qt::AlignmentFlag>(rc);
	}

int MainWindow::justIntFromEnum(Qt::AlignmentFlag eflag)
	{
	int rc;
	int intflag = eflag;
	intflag &= 0xf;
	switch(intflag)
		{
		default:
		case Qt::AlignLeft:
			rc = 0;
			break;
		case Qt::AlignHCenter:
			rc = 1;
			break;
		case Qt::AlignRight:
			rc = 2;
			break;
		}
	return rc;
	}
