// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef THOUSANDSSPINBOX_H
#define THOUSANDSSPINBOX_H

// Add thousands separators to QSpinBox.  See:
// xxx://www.listware.net/201003/qt-interest/78007-qt-interest-mismatch-between-qspinboxtextfromvalue-documentation-and-actual-behavior.html
// Link is gone, redirects to porn site.
// To use in Qt Creator, make a QSpinBox and promote it to a ThousandsSpinBox.

#include <QString>
#include <QSpinBox>

class ThousandsSpinBox : public QSpinBox
	{
	Q_OBJECT

public:
	ThousandsSpinBox(QWidget *parent = nullptr) : QSpinBox (parent) {}
	~ThousandsSpinBox() override {}

protected:
	QString textFromValue(int value) const override
		{
		return locale().toString(value);
		}
	};

#endif // THOUSANDSSPINBOX_H
