// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef VERSIONINFO_H
#define VERSIONINFO_H

// Make sure there's a single space before the version numbers.
// The installer build script parses these lines and is picky.
#define WSSINDEX_MAJOR 9
#define WSSINDEX_MINOR 3

#define STR(x) #x
#define XSTR(x) STR(x)
#define WSSINDEX_VERSION XSTR(WSSINDEX_MAJOR) "." XSTR(WSSINDEX_MINOR)

// Web file name was LatestWssindex in (broken) 8.00beta3.  Changed so anyone using
// that version will get a failure instead of being told they have the latest version.
#define VERSION_CHECK_URL	"https://www.wssddc.com/wss-ddc/LatestWssindexVersion.txt"

#define WSSINDEX_COPYRIGHT	"Copyright 1985-2022 by Robert W. Babcock and WSS Division of DDC."

// Visual Studio numbering is somewhat confusing
//   Visual C++ 2005 = Visual C++ 8.0
//   Visual C++ 2008 = Visual C++ 9.0
//   Visual C++ 2010 = Visual C++ 10.0
//   Visual C++ 2012 = Visual C++ 11.0
//   Visual C++ 2013 = Visual C++ 12.0
//   Visual C++ 2015 = Visual C++ 14.0
//   Visual C++ 2017 = Visual C++ 15.0
//   Visual C++ 2019 = Visual C++ 16.0

#ifdef BUILT_WITH_MSVC09
	#define BUILT_WITH "Visual C++ 2008 Express"
#endif

#ifdef BUILT_WITH_MSVC10
	#ifdef VER_64_BIT
		#define BUILT_WITH "Visual C++ 2010 (64-bit)"
	#else
		#define BUILT_WITH "Visual C++ 2010 (32-bit)"
	#endif
#endif

#ifdef BUILT_WITH_MSVC11
	#ifdef VER_64_BIT
		#define BUILT_WITH "Visual C++ 2012 (64-bit)"
	#else
		#define BUILT_WITH "Visual C++ 2012 (32-bit)"
	#endif
#endif

#ifdef BUILT_WITH_MSVC12
	#ifdef VER_64_BIT
		#define BUILT_WITH "Visual C++ 2013 (64-bit)"
	#else
		#define BUILT_WITH "Visual C++ 2013 (32-bit)"
	#endif
#endif

#ifdef BUILT_WITH_MSVC14
	#ifdef VER_64_BIT
		#define BUILT_WITH "Visual C++ 2015 (64-bit)"
	#else
		#define BUILT_WITH "Visual C++ 2015 (32-bit)"
	#endif
#endif

#ifdef BUILT_WITH_MSVC15
	#ifdef VER_64_BIT
		#define BUILT_WITH "Visual C++ 2017 (64-bit)"
	#else
		#define BUILT_WITH "Visual C++ 2017 (32-bit)"
	#endif
#endif
#ifdef BUILT_WITH_MSVC16
	#ifdef VER_64_BIT
		#define BUILT_WITH "Visual C++ 2019 (64-bit)"
	#else
		#define BUILT_WITH "Visual C++ 2019 (32-bit)"
	#endif
#endif
#ifdef BUILT_WITH_MinGW
	#define BUILT_WITH "MinGW C++ compiler"
#endif

#endif // VERSIONINFO_H
