// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef WSSIPROTO_H
#define WSSIPROTO_H

#include <QtGlobal>
#include <QDateTime>
#include <QComboBox>
#include <QTableWidget>

unsigned long binsrch(unsigned long diskN, unsigned long low, unsigned long high);
QDate datextract(unsigned short dmy);
QString formattedsize(quint64 size, int format);
void forceOnscreen(QWidget *widget);
void freeall(void);
int lastdot(const QString str);
QString lfnpiece(const struct filerec *dr, int which);
bool match(const QString str1, const QString str2);
bool matchNodiacritRegexp(const QRegExp rx, const QString str2, int ithread);
bool matchLfn(const QString str1, const struct filerec *dr_k);
bool matchLfnRegexp(const QRegExp rx, const struct filerec *dr_k);
bool matchLfnNodiacritRegexp(const QRegExp rx, const struct filerec *dr_k, int ithread);
void mergesort(unsigned long *array, unsigned long n, int (*cmpf)(const unsigned long, const unsigned long));
short msdosDate(QDateTime timestamp);
int namecomp(struct filerec *fn1, struct filerec *fn2, int comp1, int comp2);
long numberKey(const QString string);
int qstringCompare(const QString s1, const QString s2);
void widerCombo(QComboBox *combo);
void rootset(void);
QString & rtrimInPlace(QString &str);
void selectAllUnsorted();
void selectAllExceptIdUnsorted();
bool strserch(const QString lookfor, const QString string);
bool strserchCase(const QString lookfor, const QString string);
int threadsToUse(int force);
bool timeEqual(QDate d1, QTime t1, QDate d2, QTime t2, bool ignoreOneHour);
void time1600(struct filerec *dr, unsigned int lowtime, unsigned int hightime);
QTime timextract(unsigned short hms);
unsigned int trimblnk(char *string);
void updatePreviouslySelected(void);
bool wputs(const char *string, FILE *fp);
char *wgets(char *string, unsigned short maxbuf, FILE *fp, bool strip);
bool wsreject(unsigned long k, int ithread);
int wssicomp(const unsigned long ptr1, const unsigned long ptr2);
int wssvcomp(const unsigned long ptr1, const unsigned long ptr2);
int wssUnshrink(FILE *fp, long compLength, char *outptr, unsigned int outbufsiz);
int wssExplode(FILE *fp, unsigned short generalPurposeBitFlag,
					 unsigned long ucsize, char *result, int resultsize);
int wssInflate(FILE *fp, long compLength, char *result, int resultsize);
void unbad(char *string, int maxLength);
void unbad(QString qstring, int maxLength);
void makePrintable(char *string);
void makePrintable(QString string);
bool isTableDesignConsistent(struct fl *layout);
//void threadsafe_init_constants();
void threadsafeInit();
void updateSearchHistory(QString searchText);

#endif // WSSIPROTO_H
